
#-*- coding: utf-8 -*-
"""
Todo
----
insert module comments in this space.

"""

__title__ = "gitlab-management"
__version__ = "0.2.1rc200621083644"
__doc__ = "https://gitlab.com/nofusscomputing/projects/python-gitlab-management"
__author__ = "No Fuss Computing"
__email__ = "helpdesk@nofusscomputing.com"
__license__ = "GNU LGPLv3"
__copyright__ = "(C) All Rights reserved"
__source__ = "https://gitlab.com/nofusscomputing/projects/python-gitlab-management/-/tree/502e24e4f20a6c94c06b0f31b3bac7c2b27d1772"
